pub struct CenterHitMiss {
pub viewpoint_index: usize,
pub camera_position: [f32; 3],
pub camera_rotation_xyzw: [f32; 4],
pub health: RenderHealth,
}Expand description
Center-hit miss with enough metadata to reproduce the bad viewpoint.
Fields
viewpoint_index: usizecamera_position: [f32; 3]camera_rotation_xyzw: [f32; 4]health: RenderHealthTrait Implementations
Sourceimpl Clone for CenterHitMiss
impl Clone for CenterHitMiss
Sourcefn clone(&self) -> CenterHitMiss
fn clone(&self) -> CenterHitMiss
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CenterHitMiss
impl Debug for CenterHitMiss
Sourceimpl<'de> Deserialize<'de> for CenterHitMiss
impl<'de> Deserialize<'de> for CenterHitMiss
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CenterHitMiss
impl PartialEq for CenterHitMiss
Sourcefn eq(&self, other: &CenterHitMiss) -> bool
fn eq(&self, other: &CenterHitMiss) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CenterHitMiss
impl Serialize for CenterHitMiss
impl StructuralPartialEq for CenterHitMiss