pub fn generate_object_centered_viewpoints(
config: &ViewpointConfig,
mesh_center: Vec3,
object_rotation: &ObjectRotation,
) -> Vec<Transform>Expand description
Generate TBP viewpoint transforms around a rotated object mesh center.
Use this when the YCB mesh’s AABB center is a better render target than the
source origin. The camera orbit remains exactly the same shape as
generate_viewpoints, but centered on object_rotation * mesh_center.